<?php

namespace Drupal\graphql_address\Plugin\GraphQL\Fields\Address;

use Drupal\graphql\GraphQL\Execution\ResolveContext;
use Drupal\graphql\Plugin\GraphQL\Fields\FieldPluginBase;
use GraphQL\Type\Definition\ResolveInfo;

/**
 * The dependant localities dependant on a locality.
 *
 * @GraphQLField(
 *   secure = true,
 *   id = "address_dependant_localities",
 *   name = "dependantLocalities",
 *   parents = {"AddressLocality"},
 *   type = "[AddressDependantLocality]",
 * )
 */
class AddressDependantLocalities extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function resolveValues($value, array $args, ResolveContext $context, ResolveInfo $info) {

    // Obtain the dependant localities from a given list of parents
    // (country, admin area and locality).
    $dependant_localities = \Drupal::service('address.subdivision_repository')->getList($value['parents']);
    $parents = $value['parents'];

    /**
     * @var \CommerceGuys\Addressing\Subdivision\Subdivision $administrative_area
     */
    foreach ($dependant_localities as $locality_code => $locality) {
      // Append the dependant locality to the parents list
      $parents[] = $locality_code;
      yield [
        'result_type' => 'AddressDependantLocality',
        'name' => $locality,
        'parents' => $parents,
      ];
    }
  }

}
