<?php

namespace Drupal\graphql_address\Plugin\GraphQL\Fields\Address;

use Drupal\graphql\GraphQL\Execution\ResolveContext;
use Drupal\graphql\Plugin\GraphQL\Fields\FieldPluginBase;
use GraphQL\Type\Definition\ResolveInfo;

/**
 * A query field for a list of countries and respective address configuration.
 *
 * @GraphQLField(
 *   secure = true,
 *   id = "address",
 *   name = "addressQuery",
 *   type = "[AddressCountry]",
 *   arguments = {
 *     "countryCodes" = "[String]",
 *   },
 * )
 */
class AddressQuery extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function resolveValues($value, array $args, ResolveContext $context, ResolveInfo $info) {

    $countries = [];

    // If countries are specified we obtain config for that given countries.
    if ($args['countryCodes']) {
      foreach ($args['countryCodes'] as $code) {
        $countries[] = \Drupal::service('address.country_repository')->get($code);
      }
    }
    // Otherwise we get them all.
    else {
      $countries = \Drupal::service('address.country_repository')->getAll();
    }

    // For each country return a new GraphQL AddressCountry type including the
    // country instance.
    foreach ($countries as $country) {
      yield [
        'result_type' => 'AddressCountry',
        'country' => $country,
      ];
    }
  }

}
